@@ -15,10 +15,14 @@ import sys
 import unittest
 import subprocess
 
+try:
+    pycodestyle = subprocess.check_output(['/bin/sh', '-ec', 'which pycodestyle-3 2>/dev/null || which pycodestyle']).strip()
+except subprocess.CalledProcessError:
+    pycodestyle = None
+
 
 class StaticCodeTests(unittest.TestCase):
-    @unittest.skipIf(subprocess.call(['which', 'pyflakes'],
-                                     stdout=subprocess.PIPE) != 0,
+    @unittest.skipIf(subprocess.call(['which', 'pyflakes'], stdout=subprocess.PIPE) != 0,
                      'pyflakes not installed')
     def test_pyflakes(self):
         pyflakes = subprocess.Popen(['pyflakes', '.'], stdout=subprocess.PIPE,
@@ -26,11 +30,9 @@ class StaticCodeTests(unittest.TestCase):
         (out, err) = pyflakes.communicate()
         self.assertEqual(pyflakes.returncode, 0, out)
 
-    @unittest.skipIf(subprocess.call(['which', 'pep8'],
-                                     stdout=subprocess.PIPE) != 0,
-                     'pep8 not installed')
-    def test_pep8(self):
-        pep8 = subprocess.Popen(['pep8', '--max-line-length=130', '--ignore=E124,E402,E731', '.'],
+    @unittest.skipUnless(pycodestyle, 'pycodestyle not installed')
+    def test_codestyle(self):
+        pep8 = subprocess.Popen([pycodestyle, '--max-line-length=130', '--ignore=E124,E402,E731', '.'],
                                 stdout=subprocess.PIPE, universal_newlines=True)
         (out, err) = pep8.communicate()
         self.assertEqual(pep8.returncode, 0, out)
